@@ -8,6 +8,7 @@ from array import array
 
 from sentry.conf import settings
 from sentry.plugins import Plugin
+from sentry.models import Group
 
 import pprint
 
@@ -28,7 +29,8 @@ class TracPost(Plugin):
     def is_configured(self, project):
         return all((self.get_option(k, project) for k in ('xmlrpc_url')))
 
-    def view(self, request, group, **kwargs):
+    def send_message(self, group_id, **kwargs):
+	group = Group.object.get(pk=group_id)
         if not self.is_configured(group.project):
             return
         rpc_srv = xmlrpclib.ServerProxy(self.get_option('xmlrpc_url', group.project),allow_none=True)
